@@ -1,17 +1,21 @@
 package Function::Fallback::CoreOrPP;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-03'; # DATE
+our $DIST = 'Function-Fallback-CoreOrPP'; # DIST
+our $VERSION = '0.090'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.06'; # VERSION
-
 our $USE_NONCORE_XS_FIRST = 1;
 
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
                        clone
+                       clone_list
                        unbless
                        uniq
                );
@@ -29,6 +33,10 @@ sub clone {
     return Clone::PP::clone($data);
 }
 
+sub clone_list {
+    map { clone($_) } @_;
+}
+
 sub _unbless_fallback {
     my $ref = shift;
 
@@ -46,6 +54,8 @@ sub _unbless_fallback {
         return [ @$ref ];
     } elsif ($r3 eq 'SCALAR') {
         return \( my $copy = ${$ref} );
+    } elsif ($r3 eq 'CODE') {
+        return sub { goto &$ref };
     } else {
         die "Can't handle $ref";
     }
@@ -81,7 +91,7 @@ sub uniq {
 }
 
 1;
-#ABSTRACT: Functions that use non-core XS module but provide pure-Perl/core fallback
+# ABSTRACT: Functions that use non-core XS module but provide pure-Perl/core fallback
 
 __END__
 
@@ -95,7 +105,7 @@ Function::Fallback::CoreOrPP - Functions that use non-core XS module but provide
 
 =head1 VERSION
 
-This document describes version 0.06 of Function::Fallback::CoreOrPP (from Perl distribution Function-Fallback-CoreOrPP), released on 2014-09-16.
+This document describes version 0.090 of Function::Fallback::CoreOrPP (from Perl distribution Function-Fallback-CoreOrPP), released on 2020-02-03.
 
 =head1 SYNOPSIS
 
@@ -125,6 +135,12 @@ dependencies to your script.
 Try to use L<Data::Clone>'s C<clone>, but fall back to using L<Clone::PP>'s
 C<clone>.
 
+=head2 clone_list(@data) => @data
+
+A shortcut for:
+
+ return map {clone($_)} @data
+
 =head2 unbless($ref) => $unblessed_ref
 
 Try to use L<Acme::Damn>'s C<damn> to unbless a reference but fall back to
@@ -142,12 +158,6 @@ NOTE: The shallow copy method currently only handles blessed
 Try to use L<List::MoreUtils>'s C<uniq>, but fall back to using slower,
 pure-Perl implementation.
 
-=head1 SEE ALSO
-
-L<Clone::Any> can also uses multiple backends, but I avoid it because I don't
-think L<Storable>'s C<dclone> should be used (no Regexp support out of the box +
-must use deparse to handle coderefs).
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Function-Fallback-CoreOrPP>.
@@ -164,13 +174,20 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Clone::Any> can also use multiple backends. I used to avoid it because
+L<Storable>'s C<dclone> (which is used as the backend) did not support Regexp
+objects out of the box until version 3.08. Plus must use deparse to handle
+coderefs.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
